@@ -63,7 +63,7 @@ use Carp;
 use warnings::register;
 
 # CVS version: $Revision$
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 # Overloading
 use overload '""' => "natural",
@@ -82,7 +82,7 @@ my %TELESCOPE = (
                UKIRT => [ "CGS4", "IRCAM", "UFTI", "UIST", "MICHELLE", "WFCAM" ],
                JCMT => [ "SCUBA", "SCUBA-2",
                          "RXA3", "RXA3M", "RXB3", "RXW", "ACSIS", "DAS",
-                         "HARP", "ALAIHI", "UU", "AWEOWEO" ] );
+                         "HARP", "ALAIHI", "UU", "AWEOWEO", "KUNTUR" ] );
 
 # Continuum Filters are keyed by instrument
 # although if an instrument is not specified the filters
@@ -268,6 +268,7 @@ my %NATURAL = (
                ALAIHI => 'frequency',
                UU => 'frequency',
                AWEOWEO => 'frequency',
+               KUNTUR => 'frequency',
 	       UIST => 'filter',
 	      );
 
